/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese.properties;

import java.beans.PropertyDescriptor;

/**
 * A <code>PropertyDescriptor</code> with an added clamp feature
 */
public class ModelPropertyDescriptor {

	private PropertyDescriptor descriptor;

	private boolean clamp;

	private boolean changed;

	private Object value = null;

	/**
	 * Creates new ModelPropertyDescriptor
	 * 
	 * @param d
	 *            property descriptor
	 */
	public ModelPropertyDescriptor(PropertyDescriptor d) {
		descriptor = d;
	}

	/**
	 * Getter for property clamp.
	 * 
	 * @return Value of property clamp.
	 */
	public boolean isClamp() {
		return this.clamp;
	}

	/**
	 * Setter for property clamp.
	 * 
	 * @param clamp
	 *            New value of property clamp.
	 */
	public void setClamp(boolean clamp) {
		this.clamp = clamp;
	}

	/**
	 * Getter for property changed.
	 * 
	 * @return Value of property changed.
	 */
	public boolean isChanged() {
		return this.changed;
	}

	/**
	 * Setter for property changed.
	 * 
	 * @param changed
	 *            New value of property changed.
	 */
	public void setChanged(boolean changed) {
		this.changed = changed;
	}

	/**
	 * Setter for property value.
	 * 
	 * @param val
	 *            New value of property value.
	 */
	public void setValue(Object val) {
		if (value == null) {
			this.changed = false;
			value = val;
		}

		if (!value.equals(val)) {
			this.changed = true;
			value = val;
		} else {
			this.changed = false;
		}
	}

	/**
	 * Getter for property descriptor.
	 * 
	 * @return Value of property descriptor.
	 */
	public java.beans.PropertyDescriptor getDescriptor() {
		return this.descriptor;
	}

}