/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview.legend;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreePath;

import com.simulogic.dataview.DataView;

/**
 * Creates legend for a data interior
 */
public class LegendTree implements javax.swing.event.TreeModelListener,
        java.beans.PropertyChangeListener {

    private javax.swing.JTree tree;

    /**
     * Default constructor
     * 
     * @param v data view
     */
    public LegendTree(DataView v) {
        tree = new javax.swing.JTree(v.getStorage());
        tree.setCellEditor(new LegendTreeEditor(v));
        tree.setCellRenderer(new LegendTreeRenderer(v));
 
        tree.getSelectionModel().setSelectionMode(
                javax.swing.tree.TreeSelectionModel.SINGLE_TREE_SELECTION);
        tree.putClientProperty("JTree.lineStyle", "Angled");
        tree.setEditable(true);
        v.getStorage().addTreeModelListener(this);
        v.addPropertyChangeListener(this);
        
        tree.addTreeSelectionListener(new LegendTreeSelection(v));
    }

    /**
     * Returns tree representation of the legend
     * 
     * @return tree
     */
    public javax.swing.JTree getTreeComponent() {
        return tree;
    }

    private void expandTree(TreePath path) {
        tree.expandPath(path);
    }

    /// --- interfaces

    /**
     * Reflects change in the property (disables/enables) action
     * 
     * @param evt event
     */
    public void propertyChange(java.beans.PropertyChangeEvent evt) {
        if (evt.getPropertyName().equals("select_channel")) {
            if (evt.getOldValue() != evt.getNewValue()) {
                if ((evt.getNewValue() != null)
                        && (evt.getNewValue() instanceof DefaultMutableTreeNode)) {
                        tree.startEditingAtPath(new TreePath(
                                ((DefaultMutableTreeNode) evt.getNewValue())
                                        .getPath()));
                }
            }
        }
    }

    /**
     * @param treeModelEvent
     */
    public void treeStructureChanged(
            javax.swing.event.TreeModelEvent treeModelEvent) {
    }

    /**
     * @param treeModelEvent
     */
    public void treeNodesInserted(
            javax.swing.event.TreeModelEvent treeModelEvent) {
        expandTree(treeModelEvent.getTreePath());
    }

    /**
     * @param treeModelEvent
     */
    public void treeNodesRemoved(javax.swing.event.TreeModelEvent treeModelEvent) {
    }

    /**
     * @param treeModelEvent
     */
    public void treeNodesChanged(javax.swing.event.TreeModelEvent treeModelEvent) {
    }
}